@@ -227,7 +227,7 @@ if (Ranges == "Multiple ranges") {
                        paste(decimals(object@CILower, dps), ",", sep = ""), decimals(object@CIUpper, dps))
             output.table <- data.frame(matrix(Value, nrow = length(object@CILower), byrow=FALSE))
             colnames(output.table) <- Statistic
-            Ranges.text <- "Note: confidence interval contains multiple range of values.\n"
+            Ranges.text <- "Note: confidence interval contains multiple ranges of values.\n"
  }
 
  
@@ -245,6 +245,55 @@ if (Ranges == "Multiple ranges") {
 
 #--------------------------------------------------------------------------------------------
 
+setMethod("show",
+          "MRConMix",
+          function(object){
+
+          if (object@CIMax%in%object@CIRange & object@CIMin%in%object@CIRange) {
+   cat("Confidence interval range too narrow. Please decrease CIMin and increase CIMax and try again.") }
+         else if (object@CIMax>max(object@CIRange) & object@CIMin%in%object@CIRange) {
+   cat("Lower bound of confidence interval range too high. Please decrease CIMin and try again.") }
+          if (object@CIMax%in%object@CIRange & object@CIMin<min(object@CIRange)) {
+   cat("Upper bound of confidence interval range too low. Please increase CIMax and try again.") }
+          if (object@CIMax>max(object@CIRange) & object@CIMin<min(object@CIRange)) {
+            Interval_type <- paste(100*(1-object@Alpha), "% CI", sep = "")
+            Statistic <- c("Method", "Estimate", Interval_type, "")
+            dps = max(ceiling(-log10(object@CIStep)), 1)
+            Ranges <- ifelse(sum(diff(object@CIRange)>1.01*object@CIStep)==0, "Single range", "Multiple ranges");
+
+if (Ranges == "Single range") {
+            Value <- c("ConMix", decimals(object@Estimate, dps), 
+                       paste(decimals(min(object@CIRange), dps), ",", sep = ""), decimals(max(object@CIRange), dps))
+            output.table <- data.frame(matrix(Value, nrow = 1))
+            colnames(output.table) <- Statistic
+            Ranges.text <- "Note: confidence interval is a single range of values.\n"
+ }
+
+if (Ranges == "Multiple ranges") {
+            Value <- c("ConMix", rep("", length(object@CILower)-1),
+                       decimals(object@Estimate, dps), rep("", length(object@CILower)-1), 
+                       paste(decimals(object@CILower, dps), ",", sep = ""), decimals(object@CIUpper, dps))
+            output.table <- data.frame(matrix(Value, nrow = length(object@CILower), byrow=FALSE))
+            colnames(output.table) <- Statistic
+            Ranges.text <- "Note: confidence interval contains multiple ranges of values.\n"
+ }
+
+ 
+            cat("\nContamination mixture method\n")
+            cat("(Standard deviation of invalid estimands = ", object@Psi, ")\n\n" , sep = "")
+            cat("Number of Variants :", object@SNPs, "\n")
+
+            cat("------------------------------------------------------------------\n")
+            print(output.table, quote = F, row.names = FALSE, justify = "left")
+            cat("------------------------------------------------------------------\n")
+            cat(Ranges.text)
+            }
+      }
+)
+
+#--------------------------------------------------------------------------------------------
+
+
 setMethod("show",
           "Egger",
           function(object){
@@ -359,3 +408,38 @@ setMethod("show",
           }
 )
 
+#--------------------------------------------------------------------------------------------
+
+setMethod("show",
+          "MVEgger",
+          function(object){
+
+            Interval_type <- paste(100*(1-object@Alpha), "% CI", sep = "")
+            Statistic <- c("Exposure", "Estimate", "Std Error", Interval_type, "", "p-value")
+
+            Value <- cbind(c(object@Exposure, "(intercept)"), decimals(c(object@Estimate, object@Intercept), 3), decimals(c(object@StdError.Est, object@StdError.Int),3),
+                       paste(decimals(c(object@CILower.Est, object@CILower.Int), 3), ",", sep = ""), decimals(c(object@CIUpper.Est, object@CIUpper.Int),3),
+                             decimals(c(object@Pvalue.Est, object@Pvalue.Int), 3))
+
+            output.table <- data.frame(matrix(Value, nrow = length(object@Exposure)+1))
+            colnames(output.table) <- Statistic
+            correlation <- ifelse(sum(is.na(object@Correlation)) == 0,
+                                  "correlated", "uncorrelated")
+
+            cat("\nMultivariable MR-Egger method\n")
+            cat("(variants ", correlation, ", ", object@Model, "-effect model)\n\n" , sep = "")
+            cat("Orientated to exposure :", object@Orientate, "\n")
+            cat("Number of Variants :", object@SNPs, "\n")
+
+            cat("------------------------------------------------------------------\n")
+            print(output.table, quote = F, row.names = FALSE, justify = "left")
+            cat("------------------------------------------------------------------\n")
+
+            cat("Residual standard error = ", decimals(object@RSE, 3), "\n")
+            if(object@RSE<1) { cat("Residual standard error is set to 1 in calculation of confidence interval when its estimate is less than 1.\n") }
+            cat("Heterogeneity test statistic = ", decimals(object@Heter.Stat[1],4), " on ", object@SNPs-length(object@Exposure)-1,
+                    " degrees of freedom, (p-value = ", decimals(object@Heter.Stat[2], 4),")\n", sep = "")
+          }
+)
+
+
